Class: Steam::Response
Overview
Since the steam responses are so randomly inconsistant we're making a new class to manage the responses. FIXME: move all hash extensions here once the gem is finished and make
Since the steam responses are so randomly inconsistant we're making a new class to manage the responses. FIXME: move all hash extensions here once the gem is finished and make